@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2022 The Cacti Group                                 |
+ | Copyright (C) 2004-2024 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -136,6 +136,12 @@ $cacti_version_codes = array(
 	'1.2.21'  => '0103',
 	'1.2.22'  => '0103',
 	'1.2.23'  => '0103',
+	'1.2.24'  => '0103',
+	'1.2.25'  => '0103',
+	'1.2.26'  => '0103',
+	'1.2.27'  => '0103',
+	'1.2.28'  => '0103',
+	'1.2.29'  => '0103',
 );
 
 $messages = array(
@@ -471,13 +477,16 @@ $phperrors = array (
 	E_USER_ERROR => 'USER_ERROR',
 	E_USER_WARNING => 'USER_WARNING',
 	E_USER_NOTICE  => 'USER_NOTICE',
-	E_STRICT => 'STRICT',
 	E_RECOVERABLE_ERROR  => 'RECOVERABLE_ERROR',
 	E_DEPRECATED => 'DEPRECATED',
 	E_USER_DEPRECATED  => 'USER_DEPRECATED',
 	E_ALL => 'ALL'
 );
 
+if (version_compare(PHP_VERSION, '8.4', '<')) {
+	$phperrors[E_STRICT] = 'STRICT';
+}
+
 if (cacti_version_compare(get_rrdtool_version(), '1.8.0', '>=')) {
 	$cdef_functions[] = 'ROUND';
 }
@@ -652,9 +661,12 @@ $snmp_auth_protocols = array(
 $snmp_priv_protocols = array(
 	'[None]' => __('[None]'),
 	'DES'    => __('DES'),
+	'AES'    => __('AES'),
 	'AES128' => __('AES-128'),
 	'AES192' => __('AES-192'),
-	'AES256' => __('AES-256')
+        'AES192C' => __('AES-192-C'),
+        'AES256' => __('AES-256'),
+        'AES256C' => __('AES-256-C')
 );
 
 $banned_snmp_strings = array(
@@ -679,9 +691,10 @@ $availability_options = array(
 );
 
 $ping_methods = array(
-	PING_ICMP => __('ICMP Ping'),
-	PING_TCP  => __('TCP Ping'),
-	PING_UDP  => __('UDP Ping')
+	PING_ICMP        => __('ICMP Ping'),
+	PING_TCP         => __('TCP Ping'),
+	PING_TCP_CLOSED  => __('TCP Ping Closed'),
+	PING_UDP         => __('UDP Ping')
 );
 
 $logfile_verbosity = array(
@@ -826,6 +839,22 @@ $device_threads = array(
 	10 => __('%d Threads', 10)
 );
 
+$device_change_fields = array(
+	'preg_field' => array(
+		'/^snmp_/',
+		'/^ping_/'
+	),
+	'match_field' => array(
+		'poller_id',
+		'site_id',
+		'host_template_id',
+		'availability_method',
+		'device_threads',
+		'location',
+		'max_oids'
+	)
+);
+
 $cron_intervals = array(
 	60  => __('Every Minute'),
 	300 => __('Every %d Minutes', 5)
@@ -963,11 +992,11 @@ if ($config['poller_id'] == 1 || $config['connection'] == 'online') {
 	$menu = array(
 		__('Main Console') => array(
 			'index.php' => __('Console Page')
-			),
+		),
 		__('Create') => array(
 			'graphs_new.php' => __('New Graphs'),
 			'host.php?action=edit&create=true' => __('New Device')
-			),
+		),
 		__('Management') => array(
 			'host.php'             => __('Devices'),
 			'sites.php'            => __('Sites'),
@@ -975,49 +1004,49 @@ if ($config['poller_id'] == 1 || $config['connection'] == 'online') {
 			'graphs.php'           => __('Graphs'),
 			'data_sources.php'     => __('Data Sources'),
 			'aggregate_graphs.php' => __('Aggregates'),
-			),
+		),
 		__('Data Collection') => array(
 			'pollers.php' => __('Data Collectors'),
 			'data_queries.php' => __('Data Queries'),
 			'data_input.php'   => __('Data Input Methods')
-			),
+		),
 		__('Templates') => array(
 			'host_templates.php'      => __('Device'),
 			'graph_templates.php'     => __('Graph'),
 			'data_templates.php'      => __('Data Source'),
 			'aggregate_templates.php' => __('Aggregate'),
 			'color_templates.php'     => __('Color')
-			),
+		),
 		__('Automation') => array(
 			'automation_networks.php'    => __('Networks'),
 			'automation_devices.php'     => __('Discovered Devices'),
 			'automation_templates.php'   => __('Device Rules'),
 			'automation_graph_rules.php' => __('Graph Rules'),
 			'automation_tree_rules.php'  => __('Tree Rules'),
-			'automation_snmp.php'        => __('SNMP Options'),
-			),
+		),
 		__('Presets') => array(
 			'data_source_profiles.php' => __('Data Profiles'),
+			'automation_snmp.php'      => __('SNMP'),
 			'cdef.php'                 => __('CDEFs'),
 			'vdef.php'                 => __('VDEFs'),
 			'color.php'                => __('Colors'),
-			'gprint_presets.php'       => __('GPRINTs')
-			),
+			'gprint_presets.php'       => __('GPRINTs'),
+		),
 		__('Import/Export') => array(
 			'templates_import.php' => __('Import Templates'),
 			'package_import.php'   => __('Import Packages'),
 			'templates_export.php' => __('Export Templates')
-			),
+		),
 		__('Configuration')  => array(
 			'settings.php'         => __('Settings'),
 			'user_admin.php'       => __('Users'),
 			'user_group_admin.php' => __('User Groups'),
 			'user_domains.php'     => __('User Domains')
-			),
+		),
 		__('Utilities') => array(
 			'utilities.php'  => __('System Utilities'),
 			'links.php'      => __('External Links'),
-			),
+		),
 		__('Troubleshooting') => array(
 			'data_debug.php' => __('Data Sources'),
 		)
@@ -1070,7 +1099,10 @@ $device_classes = array(
 	'loadbalancer' => __('Load Balancer'),
 	'switch'       => __('Network Switch'),
 	'router'       => __('Network Router'),
-	'firewall'     => __('Network Firewall'),
+	'nassan'       => __('NAS/SAN Related'),
+	'firewall'     => __('Network Firewalls'),
+	'power'        => __('Power Related PDUs/STS, etc.'),
+	'printer'      => __('Printer Related'),
 	'storage'      => __('Storage Related'),
 	'telephony'    => __('Telco Related'),
 	'webserver'    => __('Web Server Related'),
@@ -1090,8 +1122,8 @@ if ((isset($_SESSION['sess_user_id']))) {
 		if (cacti_sizeof($consoles)) {
 			foreach ($consoles as $page) {
 				if (!$config['is_web'] || is_realm_allowed($page['id']+10000)) {
-					$menuname = (isset($page['extendedstyle']) && $page['extendedstyle'] != '' ? $page['extendedstyle'] : __('External Links'));
-					$menu[$menuname]['link.php?id=' . $page['id']] = $page['title'];
+					$menuname = (isset($page['extendedstyle']) && $page['extendedstyle'] != '' ? html_escape($page['extendedstyle']) : __('External Links'));
+					$menu[$menuname]['link.php?id=' . $page['id']] = html_escape($page['title']);
 				}
 			}
 		}
@@ -1300,7 +1332,6 @@ $user_auth_realm_filenames = array(
 	'color_templates_items.php' => 5,
 	'aggregate_templates.php' => 5,
 	'aggregate_graphs.php' => 5,
-	'aggregate_items.php' => 5,
 	'spikekill.php' => 1043,
 	'permission_denied.php' => -1,
 	'help.php' => -1
@@ -1585,7 +1616,7 @@ $boost_max_memory = array(
 	'5120' => __('%d GBytes', 5),
 	'6144' => __('%d GBytes', 6),
 	'8192' => __('%d GBytes', 8),
-	'-1' => __('Infinity')
+	'-1' => __('Unlimited')
 );
 
 $realtime_window = array(
@@ -2757,24 +2788,6 @@ $navigation = array(
 		'url' => '',
 		'level' => '2'
 	),
-	'aggregate_items.php:' => array(
-		'title' => __('Aggregate Items'),
-		'mapping' => 'index.php:',
-		'url' => 'aggregate_items.php',
-		'level' => '1'
-	),
-	'aggregate_items.php:item_edit' => array(
-		'title' => __('(Edit)'),
-		'mapping' => 'index.php:,aggregate_graphs.php:,aggregate_items.php:',
-		'url' => '',
-		'level' => '2'
-	),
-	'aggregate_items.php:actions' => array(
-		'title' => __('Actions'),
-		'mapping' => 'index.php:,aggregate_items.php:',
-		'url' => '',
-		'level' => '2'
-	),
 	'automation_graph_rules.php:' => array(
 		'title' => __('Graph Rules'),
 		'mapping' => 'index.php:',
